"""
This module exists only for backwards compatibility.
"""
from django.utils.translation import gettext_lazy as _
from lino.api.ad import *
